marktools.get_lilypond_comments_attached_to_component
=====================================================

.. autofunction:: abjad.tools.marktools.get_lilypond_comments_attached_to_component.get_lilypond_comments_attached_to_component
